#define _POSIX_C_SOURCE 2 /* For getopt(3) */
#include <fvsp.h>
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>

/*extern int optind;*/

int main(int argc, char **argv) {
    int opt;
    int shorten = 1;

    /* Parse options */
    optind = 0;
    while ((opt = getopt(argc, (char * const *)argv, "hlv")) != -1) {
        switch (opt) {
            case 'h':
                printf(
"Usage: fvsp [-l] [PERL_VERSION...]\n"
"       fvsp [-h|-v]\n"
"Convert Perl version strings into RPM-compatible strings. By default,\n"
"insignificant digists will be omitted from the output. The output can be\n"
"reduced up to empty string. Each positional argument is converted as a new\n"
"version string. Converted values are separated by new lines.\n"
"\n"
"  -h    show this help text and exit\n"
"  -l    long format, do not truncate insignificant parts,\n"
"        similar to Perl version-object format\n"
"  -v    show version and license information and exit\n"
);
                exit(EXIT_SUCCESS);
                break;
            case 'l':
                shorten = 0;
                break;
            case 'v':
                printf(
"This is fvsp version %s.\n"
"Copyright 2016  Petr Pisar <ppisar@redhat.com>\n"
"\n"
"This program is free software: you can redistribute it and/or modify it under\n"
"the terms of the GNU Lesser General Public License as published by the Free\n"
"Software Foundation, either version 3 of the License, or (at your option) any\n"
"later version.\n"
"\n"
"This program is distributed in the hope that it will be useful, but WITHOUT\n"
"ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS\n"
"FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more\n"
"details.\n",
    PACKAGE_VERSION
);
                exit(EXIT_SUCCESS);
                break;
            default:
                fprintf(stderr,
                        "Error: Invalid option '-%c'. Use '-h' for help.\n",
                        opt);
                exit(EXIT_FAILURE);
        }
    }

    /* Convert other arguments as version strings */
    for (; optind < argc; optind++) {
        char *output = vsp(argv[optind], shorten);
        if (NULL == output) {
            fprintf(stderr, "Error while converting '%s'.\n", output);
            exit(EXIT_FAILURE);
        }
        printf("%s\n", output);
        free(output);
    }

    exit(EXIT_SUCCESS);
}
